@@ -1,10 +1,9 @@
-describe('Basic html theme search', function() {
-
+describe("Basic html theme search", function () {
   function loadFixture(name) {
-      req = new XMLHttpRequest();
-      req.open("GET", `__src__/tests/js/fixtures/${name}`, false);
-      req.send(null);
-      return req.responseText;
+    req = new XMLHttpRequest();
+    req.open("GET", `__src__/tests/js/fixtures/${name}`, false);
+    req.send(null);
+    return req.responseText;
   }
 
   function checkRanking(expectedRanking, results) {
@@ -16,7 +15,11 @@ describe('Basic html theme search', function() {
       let [expectedPage, expectedTitle, expectedTarget] = nextExpected;
       let [page, title, target] = result;
 
-      if (page == expectedPage && title == expectedTitle && target == expectedTarget) {
+      if (
+        page == expectedPage
+        && title == expectedTitle
+        && target == expectedTarget
+      ) {
         [nextExpected, ...remainingItems] = remainingItems;
       }
     }
@@ -25,16 +28,17 @@ describe('Basic html theme search', function() {
     expect(nextExpected).toEqual(undefined);
   }
 
-  describe('terms search', function() {
-
-    it('should find "C++" when in index', function() {
+  describe("terms search", function () {
+    it('should find "C++" when in index', function () {
       eval(loadFixture("cpp/searchindex.js"));
 
-      [_searchQuery, searchterms, excluded, ..._remainingItems] = Search._parseQuery('C++');
+      [_searchQuery, searchterms, excluded, ..._remainingItems] =
+        Search._parseQuery("C++");
 
+      // prettier-ignore
       hits = [[
         "index",
-        "&lt;no title&gt;",
+        "<no title>",
         "",
         null,
         5,
@@ -44,10 +48,12 @@ describe('Basic html theme search', function() {
       expect(Search.performTermsSearch(searchterms, excluded)).toEqual(hits);
     });
 
-    it('should be able to search for multiple terms', function() {
+    it("should be able to search for multiple terms", function () {
       eval(loadFixture("multiterm/searchindex.js"));
 
-      [_searchQuery, searchterms, excluded, ..._remainingItems] = Search._parseQuery('main page');
+      [_searchQuery, searchterms, excluded, ..._remainingItems] =
+        Search._parseQuery("main page");
+      // prettier-ignore
       hits = [[
         'index',
         'Main Page',
@@ -60,11 +66,13 @@ describe('Basic html theme search', function() {
       expect(Search.performTermsSearch(searchterms, excluded)).toEqual(hits);
     });
 
-    it('should partially-match "sphinx" when in title index', function() {
+    it('should partially-match "sphinx" when in title index', function () {
       eval(loadFixture("partial/searchindex.js"));
 
-      [_searchQuery, searchterms, excluded, ..._remainingItems] = Search._parseQuery('sphinx');
+      [_searchQuery, searchterms, excluded, ..._remainingItems] =
+        Search._parseQuery("sphinx");
 
+      // prettier-ignore
       hits = [[
         "index",
         "sphinx_utils module",
@@ -77,13 +85,15 @@ describe('Basic html theme search', function() {
       expect(Search.performTermsSearch(searchterms, excluded)).toEqual(hits);
     });
 
-    it('should partially-match within "possible" when in term index', function() {
+    it('should partially-match within "possible" when in term index', function () {
       eval(loadFixture("partial/searchindex.js"));
 
-      [_searchQuery, searchterms, excluded, ..._remainingItems] = Search._parseQuery('ossibl');
+      [_searchQuery, searchterms, excluded, ..._remainingItems] =
+        Search._parseQuery("ossibl");
       terms = Search._index.terms;
       titleterms = Search._index.titleterms;
 
+      // prettier-ignore
       hits = [[
         "index",
         "sphinx_utils module",
@@ -93,18 +103,19 @@ describe('Basic html theme search', function() {
         "index.rst",
         "text"
       ]];
-      expect(Search.performTermsSearch(searchterms, excluded, terms, titleterms)).toEqual(hits);
+      expect(
+        Search.performTermsSearch(searchterms, excluded, terms, titleterms),
+      ).toEqual(hits);
     });
-
   });
 
-  describe('aggregation of search results', function() {
-
-    it('should combine document title and document term matches', function() {
+  describe("aggregation of search results", function () {
+    it("should combine document title and document term matches", function () {
       eval(loadFixture("multiterm/searchindex.js"));
 
-      searchParameters = Search._parseQuery('main page');
+      searchParameters = Search._parseQuery("main page");
 
+      // prettier-ignore
       hits = [
         [
           'index',
@@ -118,11 +129,9 @@ describe('Basic html theme search', function() {
       ];
       expect(Search._performSearch(...searchParameters)).toEqual(hits);
     });
-
   });
 
-  describe('search result ranking', function() {
-
+  describe("search result ranking", function () {
     /*
      * These tests should not proscribe precise expected ordering of search
      * results; instead each test case should describe a single relevance rule
@@ -137,95 +146,96 @@ describe('Basic html theme search', function() {
      * [1] - https://github.com/sphinx-doc/sphinx.git/
      */
 
-    it('should score a code module match above a page-title match', function() {
+    it("should score a code module match above a page-title match", function () {
       eval(loadFixture("titles/searchindex.js"));
 
+      // prettier-ignore
       expectedRanking = [
         ['index', 'relevance', '#module-relevance'],  /* py:module documentation */
         ['relevance', 'Relevance', ''],  /* main title */
       ];
 
-      searchParameters = Search._parseQuery('relevance');
+      searchParameters = Search._parseQuery("relevance");
       results = Search._performSearch(...searchParameters);
 
       checkRanking(expectedRanking, results);
     });
 
-    it('should score a main-title match above an object member match', function() {
+    it("should score a main-title match above an object member match", function () {
       eval(loadFixture("titles/searchindex.js"));
 
+      // prettier-ignore
       expectedRanking = [
         ['relevance', 'Relevance', ''],  /* main title */
         ['index', 'relevance.Example.relevance', '#relevance.Example.relevance'],  /* py:class attribute */
       ];
 
-      searchParameters = Search._parseQuery('relevance');
+      searchParameters = Search._parseQuery("relevance");
       results = Search._performSearch(...searchParameters);
 
       checkRanking(expectedRanking, results);
     });
 
-    it('should score a title match above a standard index entry match', function() {
+    it("should score a title match above a standard index entry match", function () {
       eval(loadFixture("titles/searchindex.js"));
 
+      // prettier-ignore
       expectedRanking = [
         ['relevance', 'Relevance', ''],  /* title */
         ['index', 'Main Page', '#index-1'],  /* index entry */
       ];
 
-      searchParameters = Search._parseQuery('relevance');
+      searchParameters = Search._parseQuery("relevance");
       results = Search._performSearch(...searchParameters);
 
       checkRanking(expectedRanking, results);
     });
 
-    it('should score a priority index entry match above a title match', function() {
+    it("should score a priority index entry match above a title match", function () {
       eval(loadFixture("titles/searchindex.js"));
 
+      // prettier-ignore
       expectedRanking = [
         ['index', 'Main Page', '#index-0'],  /* index entry */
         ['index', 'Main Page > Result Scoring', '#result-scoring'],  /* title */
       ];
 
-      searchParameters = Search._parseQuery('scoring');
+      searchParameters = Search._parseQuery("scoring");
       results = Search._performSearch(...searchParameters);
 
       checkRanking(expectedRanking, results);
     });
 
-    it('should score a main-title match above a subheading-title match', function() {
+    it("should score a main-title match above a subheading-title match", function () {
       eval(loadFixture("titles/searchindex.js"));
 
+      // prettier-ignore
       expectedRanking = [
         ['relevance', 'Relevance', ''],  /* main title */
         ['index', 'Main Page > Relevance', '#relevance'],  /* subsection heading title */
       ];
 
-      searchParameters = Search._parseQuery('relevance');
+      searchParameters = Search._parseQuery("relevance");
       results = Search._performSearch(...searchParameters);
 
       checkRanking(expectedRanking, results);
     });
-
   });
 
-  describe('can handle edge-case search queries', function() {
-
-    it('does not find the javascript prototype property in unrelated documents', function() {
+  describe("can handle edge-case search queries", function () {
+    it("does not find the javascript prototype property in unrelated documents", function () {
       eval(loadFixture("partial/searchindex.js"));
 
-      searchParameters = Search._parseQuery('__proto__');
+      searchParameters = Search._parseQuery("__proto__");
 
+      // prettier-ignore
       hits = [];
       expect(Search._performSearch(...searchParameters)).toEqual(hits);
     });
-
   });
-
 });
 
-describe("htmlToText", function() {
-
+describe("htmlToText", function () {
   const testHTML = `<html>
   <body>
     <script src="directory/filename.js"></script>
@@ -257,44 +267,47 @@ describe("htmlToText", function() {
   </html>`;
 
   it("basic case", () => {
-    expect(Search.htmlToText(testHTML).trim().split(/\s+/)).toEqual([
-      'Getting', 'Started', 'Some', 'text',
-      'Other', 'Section', 'Other', 'text',
-      'Yet', 'Another', 'Section', 'More', 'text'
-    ]);
+    expect(Search.htmlToText(testHTML).trim().split(/\s+/)).toEqual(
+      /* prettier-ignore */ [
+      "Getting", "Started", "Some", "text",
+      "Other", "Section", "Other", "text",
+      "Yet", "Another", "Section", "More", "text"
+    ],
+    );
   });
 
   it("will start reading from the anchor", () => {
-    expect(Search.htmlToText(testHTML, '#other-section').trim().split(/\s+/)).toEqual(['Other', 'Section', 'Other', 'text']);
+    expect(
+      Search.htmlToText(testHTML, "#other-section").trim().split(/\s+/),
+    ).toEqual(["Other", "Section", "Other", "text"]);
   });
 });
 
 // Regression test for https://github.com/sphinx-doc/sphinx/issues/3150
-describe('splitQuery regression tests', () => {
+describe("splitQuery regression tests", () => {
+  it("can split English words", () => {
+    const parts = splitQuery("   Hello    World   ");
+    expect(parts).toEqual(["Hello", "World"]);
+  });
 
-  it('can split English words', () => {
-    const parts = splitQuery('   Hello    World   ')
-    expect(parts).toEqual(['Hello', 'World'])
-  })
+  it("can split special characters", () => {
+    const parts = splitQuery("Pin-Code");
+    expect(parts).toEqual(["Pin", "Code"]);
+  });
 
-  it('can split special characters', () => {
-    const parts = splitQuery('Pin-Code')
-    expect(parts).toEqual(['Pin', 'Code'])
-  })
+  it("can split Chinese characters", () => {
+    const parts = splitQuery("Hello from 中国 上海");
+    expect(parts).toEqual(["Hello", "from", "中国", "上海"]);
+  });
 
-  it('can split Chinese characters', () => {
-    const parts = splitQuery('Hello from 中国 上海')
-    expect(parts).toEqual(['Hello', 'from', '中国', '上海'])
-  })
+  it("can split Emoji (surrogate pair) characters. It should keep emojis.", () => {
+    const parts = splitQuery("😁😁");
+    expect(parts).toEqual(["😁😁"]);
+  });
 
-  it('can split Emoji (surrogate pair) characters. It should keep emojis.', () => {
-    const parts = splitQuery('😁😁')
-    expect(parts).toEqual(['😁😁'])
-  })
-
-  it('can split umlauts. It should keep umlauts.', () => {
-    const parts = splitQuery('Löschen Prüfung Abändern ærlig spørsmål')
-    expect(parts).toEqual(['Löschen', 'Prüfung', 'Abändern', 'ærlig', 'spørsmål'])
-  })
-
-})
+  it("can split umlauts. It should keep umlauts.", () => {
+    const parts = splitQuery("Löschen Prüfung Abändern ærlig spørsmål");
+    // prettier-ignore
+    expect(parts).toEqual(["Löschen", "Prüfung", "Abändern", "ærlig", "spørsmål"])
+  });
+});
